@@ -391,6 +391,15 @@ bool ObjectiveHandler::String(const char *str, std::size_t length, bool) {
 bool LearnerParamHandler::String(const char *str,
                                  std::size_t,
                                  bool) {
+  int num_target = 1;
+  if (assign_value("num_target", std::atoi(str), num_target)) {
+    if (num_target != 1) {
+      TREELITE_LOG(ERROR)
+        << "num_target must be 1; Treelite doesn't support multi-target regressor yet";
+      return false;
+    }
+    return true;
+  }
   return (assign_value("base_score", strtof(str, nullptr),
                        output.param.global_bias) ||
           assign_value("num_class", static_cast<unsigned int>(std::max(std::atoi(str), 1)),
@@ -422,16 +431,31 @@ bool LearnerHandler::StartArray() {
           push_key_handler<IgnoreHandler>("feature_types"));
 }
 
+/******************************************************************************
+ * XGBoostCheckpointHandler
+ * ***************************************************************************/
+
+bool XGBoostCheckpointHandler::StartArray() {
+  return push_key_handler<ArrayHandler<unsigned>, std::vector<unsigned>>(
+      "version", output.version);
+}
+
+bool XGBoostCheckpointHandler::StartObject() {
+  return push_key_handler<LearnerHandler, XGBoostModelHandle>("learner", output);
+}
+
 /******************************************************************************
  * XGBoostModelHandler
  * ***************************************************************************/
 bool XGBoostModelHandler::StartArray() {
   return push_key_handler<ArrayHandler<unsigned>, std::vector<unsigned>>(
-      "version", version);
+      "version", output.version);
 }
 
 bool XGBoostModelHandler::StartObject() {
-  return push_key_handler<LearnerHandler, XGBoostModelHandle>("learner", output);
+  return (push_key_handler<LearnerHandler, XGBoostModelHandle>("learner", output) ||
+          push_key_handler<IgnoreHandler>("Config") ||
+          push_key_handler<XGBoostCheckpointHandler, XGBoostModelHandle>("Model", output));
 }
 
 bool XGBoostModelHandler::EndObject(std::size_t memberCount) {
@@ -453,7 +477,7 @@ bool XGBoostModelHandler::EndObject(std::size_t memberCount) {
   }
   // Before XGBoost 1.0.0, the global bias saved in model is a transformed value.  After
   // 1.0 it's the original value provided by user.
-  const bool need_transform_to_margin = (version[0] >= 1);
+  const bool need_transform_to_margin = (output.version[0] >= 1);
   if (need_transform_to_margin) {
     treelite::details::xgboost::TransformGlobalBiasToMargin(&output.model->param);
   }
@@ -464,7 +488,7 @@ bool XGBoostModelHandler::EndObject(std::size_t memberCount) {
  * RootHandler
  * ***************************************************************************/
 bool RootHandler::StartObject() {
-  handle = {dynamic_cast<treelite::ModelImpl<float, float>*>(output.get()), ""};
+  handle = {dynamic_cast<treelite::ModelImpl<float, float>*>(output.get()), {}, ""};
   return push_handler<XGBoostModelHandler, XGBoostModelHandle>(handle);
 }
 
